==> haskell-profunctors-5.6.3-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.3
visibility:           public
id:                   profunctors-5.6.3-31Z97EsBcOl3NoMlhVYNxE
key:                  profunctors-5.6.3-31Z97EsBcOl3NoMlhVYNxE
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  0cd2cae7281afaeabafbb5d98400a7e7
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.3-31Z97EsBcOl3NoMlhVYNxE
depends:
    base-4.17.2.1 base-orphans-0.9.3-KjEwzlW93pECocqzLBwG3l
    bifunctors-5.6.2-3SRqtSObL6qDHPufpMyPce
    comonad-5.0.9-HhbbzCqu8yXCinyU8dzPDS
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-GNR94MI017VFyaErcDbjsB
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.6.3-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.3
visibility:           public
id:                   profunctors-5.6.3-1MRdcva7iD2KhEGv1D037x
key:                  profunctors-5.6.3-1MRdcva7iD2KhEGv1D037x
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  9a654453b69746aa71de13c6920c82d9
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.3-1MRdcva7iD2KhEGv1D037x
depends:
    base-4.17.2.1 base-orphans-0.9.3-K0jSnIfYlPW34ZON03RGHV
    bifunctors-5.6.2-Do5GrIbf3Io83XnZDLbpjy
    comonad-5.0.9-ElYJ8dJHwQS2Hj5UoiqgAW
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-4BGER1sRuBBJLqHRISW5MJ
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
